@@ -6,7 +6,6 @@ https://github.com/zabuldon/teslajsonpy
 """
 import logging
 from typing import Dict, Text
-from teslajsonpy.const import TESLA_DEFAULT_ENERGY_SITE_NAME
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -35,7 +34,7 @@ class EnergySiteDevice:
         """
         self._id: int = data["id"]
         self._energy_site_id: int = data["energy_site_id"]
-        self._site_name: Text = data.get("site_name", TESLA_DEFAULT_ENERGY_SITE_NAME)
+        self._site_name: Text = data.get("site_name", f"{self._energy_site_id}")
         self._solar_type: Text = data["solar_type"]
         self._controller = controller
         self.should_poll: bool = True
@@ -135,9 +134,8 @@ class PowerSensor(EnergySiteDevice):
         super().refresh()
         data = self._controller.get_power_params(self._id)
         if data:
-            if "grid_status" in data and data["grid_status"] == "Unknown":
-                return
-
+            # Note: Some systems that pre-date Tesla aquisition of SolarCity will have `grid_status: Unknown`,
+            # but will have solar power values
             self.__power = data["solar_power"]
             if data["solar_power"] is not None:
                 self.__generating_status = (
